<?php

namespace Luticate\Auth\Controller;

use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Utils\LuController;
use Luticate\Auth\Business\LuticatePermissionsBusiness;
use Luticate\Auth\DBO\LuticatePermissionsDbo;

class LuticatePermissionsController extends LuController {
    protected function getBusiness()
    {
        return new LuticatePermissionsBusiness();
    }

    /**
     * Get the effective permission for a user
     * @param $user_id int The user id
     * @param $permission_name string The permission name
     * @return LuticatePermissionsDbo
     */
    public function getEffectivePermission($user_id, $permission_name)
    {
        return LuticatePermissionsBusiness::getEffectivePermission($user_id, $permission_name);
    }

    /**
     * Get the effective permission for the logged user
     * @param $_user LuticateUsersDbo Logged user
     * @param $permission_name string The permission name
     * @return LuticatePermissionsDbo
     */
    public function getEffectivePermissionMe($_user, $permission_name)
    {
        return LuticatePermissionsBusiness::getEffectivePermission($_user->getId(), $permission_name);
    }

    /**
     * Get all the effective permission for a user
     * @param $user_id int The user id
     * @return LuticatePermissionsDbo
     */
    public function getAllEffectivePermission($user_id)
    {
        return LuticatePermissionsBusiness::getAllEffectivePermission($user_id);
    }

    /**
     * Get all the effective permission for the logged user
     * @param $_user LuticateUsersDbo Logged user
     * @return LuticatePermissionsDbo
     */
    public function getAllEffectivePermissionMe($_user)
    {
        return LuticatePermissionsBusiness::getAllEffectivePermission($_user->getId());
    }

    /**
     * Get a permission
     * @param $permission_name string The permission name
     * @return \Luticate\Utils\LuDbo
     */
    public function get($permission_name)
    {
        return LuticatePermissionsBusiness::get($permission_name);
    }

    /**
     * Get all permissions
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @param string $query The filter query
     * @return \Luticate\Utils\LuMultipleDbo
     */
    public function getAll($page = 0, $perPage = PHP_INT_MAX, $query = "")
    {
        return LuticatePermissionsBusiness::getAll($page, $perPage, $query);
    }

    /**
     * Add a permission
     * @param $permission_name string The permission name
     * @param $permission_value bool The default permission value
     * @return bool
     */
    public function add($permission_name, $permission_value)
    {
        return LuticatePermissionsBusiness::add($permission_name, $permission_value);
    }

    /**
     * Remove a permission
     * @param $permission_name string The permission name
     * @return bool
     */
    public function del($permission_name)
    {
        return LuticatePermissionsBusiness::del($permission_name);
    }

    /**
     * Edit the default permission value
     * @param $permission_name string The permission name
     * @param $permission_value bool The default permission value
     * @return bool
     */
    public function edit($permission_name, $permission_value)
    {
        return LuticatePermissionsBusiness::edit($permission_name, $permission_value);
    }
}